# Generated by Django 4.2.14 on 2024-11-14 10:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_requests_loger', '0002_requestlog_cache_data'),
    ]

    operations = [
        migrations.AlterField(
            model_name='requestlog',
            name='duration',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
